@@ -26,7 +26,7 @@ import (
 	"knative.dev/pkg/apis"
 	"knative.dev/pkg/apis/duck"
 	duckv1 "knative.dev/pkg/apis/duck/v1"
-	apitestv1 "knative.dev/pkg/apis/testing/v1"
+	apistest "knative.dev/pkg/apis/testing"
 	"knative.dev/pkg/ptr"
 	"knative.dev/serving/pkg/apis/autoscaling"
 )
@@ -470,43 +470,43 @@ func TestTargetAnnotation(t *testing.T) {
 		name       string
 		pa         *PodAutoscaler
 		wantTarget float64
-		wantOk     bool
+		wantOK     bool
 	}{{
 		name:       "not present",
 		pa:         pa(map[string]string{}),
 		wantTarget: 0,
-		wantOk:     false,
+		wantOK:     false,
 	}, {
 		name: "present",
 		pa: pa(map[string]string{
 			autoscaling.TargetAnnotationKey: "1",
 		}),
 		wantTarget: 1,
-		wantOk:     true,
+		wantOK:     true,
 	}, {
 		name: "present float",
 		pa: pa(map[string]string{
 			autoscaling.TargetAnnotationKey: "19.82",
 		}),
 		wantTarget: 19.82,
-		wantOk:     true,
+		wantOK:     true,
 	}, {
 		name: "invalid format",
 		pa: pa(map[string]string{
 			autoscaling.TargetAnnotationKey: "sandwich",
 		}),
 		wantTarget: 0,
-		wantOk:     false,
+		wantOK:     false,
 	}}
 
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
-			gotTarget, gotOk := tc.pa.Target()
+			gotTarget, gotOK := tc.pa.Target()
 			if gotTarget != tc.wantTarget {
 				t.Errorf("got target: %v wanted: %v", gotTarget, tc.wantTarget)
 			}
-			if gotOk != tc.wantOk {
-				t.Errorf("got ok: %v wanted %v", gotOk, tc.wantOk)
+			if gotOK != tc.wantOK {
+				t.Errorf("got ok: %v wanted %v", gotOK, tc.wantOK)
 			}
 		})
 	}
@@ -606,7 +606,7 @@ func TestMarkResourceNotOwned(t *testing.T) {
 func TestMarkResourceFailedCreation(t *testing.T) {
 	pa := &PodAutoscalerStatus{}
 	pa.MarkResourceFailedCreation("doesn't", "matter")
-	apitestv1.CheckConditionFailed(pa.duck(), PodAutoscalerConditionActive, t)
+	apistest.CheckConditionFailed(pa, PodAutoscalerConditionActive, t)
 
 	active := pa.GetCondition("Active")
 	if active.Status != corev1.ConditionFalse {
@@ -702,36 +702,36 @@ func TestWindowAnnotation(t *testing.T) {
 		name       string
 		pa         *PodAutoscaler
 		wantWindow time.Duration
-		wantOk     bool
+		wantOK     bool
 	}{{
 		name:       "not present",
 		pa:         pa(map[string]string{}),
 		wantWindow: 0,
-		wantOk:     false,
+		wantOK:     false,
 	}, {
 		name: "present",
 		pa: pa(map[string]string{
 			autoscaling.WindowAnnotationKey: "120s",
 		}),
 		wantWindow: time.Second * 120,
-		wantOk:     true,
+		wantOK:     true,
 	}, {
 		name: "invalid",
 		pa: pa(map[string]string{
 			autoscaling.WindowAnnotationKey: "365d",
 		}),
 		wantWindow: 0,
-		wantOk:     false,
+		wantOK:     false,
 	}}
 
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
-			gotWindow, gotOk := tc.pa.Window()
+			gotWindow, gotOK := tc.pa.Window()
 			if gotWindow != tc.wantWindow {
 				t.Errorf("%q expected target: %v got: %v", tc.name, tc.wantWindow, gotWindow)
 			}
-			if gotOk != tc.wantOk {
-				t.Errorf("%q expected ok: %v got %v", tc.name, tc.wantOk, gotOk)
+			if gotOK != tc.wantOK {
+				t.Errorf("%q expected ok: %v got %v", tc.name, tc.wantOK, gotOK)
 			}
 		})
 	}
@@ -742,36 +742,36 @@ func TestPanicWindowPercentageAnnotation(t *testing.T) {
 		name           string
 		pa             *PodAutoscaler
 		wantPercentage float64
-		wantOk         bool
+		wantOK         bool
 	}{{
 		name:           "not present",
 		pa:             pa(map[string]string{}),
 		wantPercentage: 0.0,
-		wantOk:         false,
+		wantOK:         false,
 	}, {
 		name: "present",
 		pa: pa(map[string]string{
 			autoscaling.PanicWindowPercentageAnnotationKey: "10.0",
 		}),
 		wantPercentage: 10.0,
-		wantOk:         true,
+		wantOK:         true,
 	}, {
 		name: "malformed",
 		pa: pa(map[string]string{
 			autoscaling.PanicWindowPercentageAnnotationKey: "sandwich",
 		}),
 		wantPercentage: 0.0,
-		wantOk:         false,
+		wantOK:         false,
 	}}
 
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
-			gotPercentage, gotOk := tc.pa.PanicWindowPercentage()
+			gotPercentage, gotOK := tc.pa.PanicWindowPercentage()
 			if gotPercentage != tc.wantPercentage {
 				t.Errorf("%q expected target: %v got: %v", tc.name, tc.wantPercentage, gotPercentage)
 			}
-			if gotOk != tc.wantOk {
-				t.Errorf("%q expected ok: %v got %v", tc.name, tc.wantOk, gotOk)
+			if gotOK != tc.wantOK {
+				t.Errorf("%q expected ok: %v got %v", tc.name, tc.wantOK, gotOK)
 			}
 		})
 	}
@@ -822,29 +822,29 @@ func TestPanicThresholdPercentage(t *testing.T) {
 		name           string
 		pa             *PodAutoscaler
 		wantPercentage float64
-		wantOk         bool
+		wantOK         bool
 	}{{
 		name:           "not present",
 		pa:             pa(map[string]string{}),
 		wantPercentage: 0.0,
-		wantOk:         false,
+		wantOK:         false,
 	}, {
 		name: "present",
 		pa: pa(map[string]string{
 			autoscaling.PanicThresholdPercentageAnnotationKey: "300.0",
 		}),
 		wantPercentage: 300.0,
-		wantOk:         true,
+		wantOK:         true,
 	}}
 
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
-			gotPercentage, gotOk := tc.pa.PanicThresholdPercentage()
+			gotPercentage, gotOK := tc.pa.PanicThresholdPercentage()
 			if gotPercentage != tc.wantPercentage {
 				t.Errorf("%q expected target: %v got: %v", tc.name, tc.wantPercentage, gotPercentage)
 			}
-			if gotOk != tc.wantOk {
-				t.Errorf("%q expected ok: %v got %v", tc.name, tc.wantOk, gotOk)
+			if gotOK != tc.wantOK {
+				t.Errorf("%q expected ok: %v got %v", tc.name, tc.wantOK, gotOK)
 			}
 		})
 	}
@@ -868,38 +868,38 @@ func pa(annotations map[string]string) *PodAutoscaler {
 func TestTypicalFlow(t *testing.T) {
 	r := &PodAutoscalerStatus{}
 	r.InitializeConditions()
-	apitestv1.CheckConditionOngoing(r.duck(), PodAutoscalerConditionActive, t)
-	apitestv1.CheckConditionOngoing(r.duck(), PodAutoscalerConditionReady, t)
+	apistest.CheckConditionOngoing(r, PodAutoscalerConditionActive, t)
+	apistest.CheckConditionOngoing(r, PodAutoscalerConditionReady, t)
 
 	// When we see traffic, mark ourselves active.
 	r.MarkActive()
-	apitestv1.CheckConditionSucceeded(r.duck(), PodAutoscalerConditionActive, t)
-	apitestv1.CheckConditionSucceeded(r.duck(), PodAutoscalerConditionReady, t)
+	apistest.CheckConditionSucceeded(r, PodAutoscalerConditionActive, t)
+	apistest.CheckConditionSucceeded(r, PodAutoscalerConditionReady, t)
 
 	// Check idempotency.
 	r.MarkActive()
-	apitestv1.CheckConditionSucceeded(r.duck(), PodAutoscalerConditionActive, t)
-	apitestv1.CheckConditionSucceeded(r.duck(), PodAutoscalerConditionReady, t)
+	apistest.CheckConditionSucceeded(r, PodAutoscalerConditionActive, t)
+	apistest.CheckConditionSucceeded(r, PodAutoscalerConditionReady, t)
 
-	// When we stop seeing traffic, mark outselves inactive.
+	// When we stop seeing traffic, mark ourselves inactive.
 	r.MarkInactive("TheReason", "the message")
-	apitestv1.CheckConditionFailed(r.duck(), PodAutoscalerConditionActive, t)
+	apistest.CheckConditionFailed(r, PodAutoscalerConditionActive, t)
 	if !r.IsInactive() {
-		t.Errorf("IsInactive was not set.")
+		t.Error("IsInactive was not set.")
 	}
-	apitestv1.CheckConditionFailed(r.duck(), PodAutoscalerConditionReady, t)
+	apistest.CheckConditionFailed(r, PodAutoscalerConditionReady, t)
 
 	// When traffic hits the activator and we scale up the deployment we mark
 	// ourselves as activating.
 	r.MarkActivating("Activating", "Red team, GO!")
-	apitestv1.CheckConditionOngoing(r.duck(), PodAutoscalerConditionActive, t)
-	apitestv1.CheckConditionOngoing(r.duck(), PodAutoscalerConditionReady, t)
+	apistest.CheckConditionOngoing(r, PodAutoscalerConditionActive, t)
+	apistest.CheckConditionOngoing(r, PodAutoscalerConditionReady, t)
 
 	// When the activator successfully forwards traffic to the deployment,
 	// we mark ourselves as active once more.
 	r.MarkActive()
-	apitestv1.CheckConditionSucceeded(r.duck(), PodAutoscalerConditionActive, t)
-	apitestv1.CheckConditionSucceeded(r.duck(), PodAutoscalerConditionReady, t)
+	apistest.CheckConditionSucceeded(r, PodAutoscalerConditionActive, t)
+	apistest.CheckConditionSucceeded(r, PodAutoscalerConditionReady, t)
 }
 
 func TestTargetBC(t *testing.T) {
